summaryrefslogtreecommitdiffstats
path: root/akregator/src/tagset.h
diff options
context:
space:
mode:
Diffstat (limited to 'akregator/src/tagset.h')
-rw-r--r--akregator/src/tagset.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/akregator/src/tagset.h b/akregator/src/tagset.h
index aea004c8..febb47d3 100644
--- a/akregator/src/tagset.h
+++ b/akregator/src/tagset.h
@@ -62,11 +62,11 @@ class TagSet : public QObject
/** returns the tag set as map ((id, Tag) pairs) */
TQMap<TQString,Tag> toMap() const;
- /** returns @c true if this set contains @c tag */
- bool contains(const Tag& tag) const;
+ /** returns @c true if this set tqcontains @c tag */
+ bool tqcontains(const Tag& tag) const;
- /** returns @c true if this set contains a tag with a given ID */
- bool containsID(const TQString& id) const;
+ /** returns @c true if this set tqcontains a tag with a given ID */
+ bool tqcontainsID(const TQString& id) const;
/** returns the tag with the given ID if the tag is element of the set, or a null tag if not */
Tag findByID(const TQString& id) const;